==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/sonnet/plugins/hspell/kspell_hspellclient.h <==
/**
 * kspell_hspellclient.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 * Copyright (C)  2005  Mashrab Kuvatov <kmashrab@uni-bremen.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_HSPELLCLIENT_H
#define KSPELL_HSPELLCLIENT_H

#include "client.h"
#include <qobject.h>

/* libhspell is a C library and it does not have #ifdef __cplusplus */
extern "C" {
#include "hspell.h"
}

namespace KSpell2 {
    class Speller;
}
using KSpell2::Speller;

class HSpellClient : public KSpell2::Client
{
    Q_OBJECT
public:
    HSpellClient( QObject *parent, const QStringList & /* args */  );
    ~HSpellClient();

    virtual int reliability() const {
        return 20;
    }

    virtual Speller* createSpeller( const QString& language );

    virtual QStringList languages() const;

    virtual QString name() const {
        return "HSpell";
    }
private:

};

#endif

==> kde4libs_3.93.0.orig.tar.gz: kde4libs-3.93.0.orig/sonnet/plugins/hspell/kspell_hspellclient.h <==
/**
 * kspell_hspellclient.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 * Copyright (C)  2005  Mashrab Kuvatov <kmashrab@uni-bremen.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_HSPELLCLIENT_H
#define KSPELL_HSPELLCLIENT_H

#include "client_p.h"
#include <QtCore/QObject>

/* libhspell is a C library and it does not have #ifdef __cplusplus */
extern "C" {
#include "hspell.h"
}

namespace Sonnet {
    class SpellerPlugin;
}
using Sonnet::SpellerPlugin;

class HSpellClient : public Sonnet::Client
{
    Q_OBJECT
public:
    HSpellClient(QObject *parent, const QStringList &/* args */);
    ~HSpellClient();

    virtual int reliability() const {
        return 20;
    }

    virtual SpellerPlugin *createSpeller(const QString &language);

    virtual QStringList languages() const;

    virtual QString name() const {
        return "HSpell";
    }
private:

};

#endif
